/*
m_scene_bell_noise - A sound alike effect of old American phone noise

DESCRIPTION
m_scene_bell_noise is an audio effect. It's a sound alike of old American
phone line background noise, as heard in the late 60s to early 80s.

SYNTAX
aOut m_scene_bell_noise kBleed, kBass, kBuzz, kType

INITIALIZATION

PERFORMANCE
aOut - An sound-alike of old American telephone background noise
kBleed - Bleed component from idle switching equipment, between 0 and 1
kBass - Bass hum component, between 0 and 1
kBuzz - Buzzy and hissy component, between 0 and 1
kType - Type of noise or connection, possible values:
	0: local
	1: long distance

CREDITS
Author: Jeanette C., thanks to Evan Doorbell and other phone phreaks of the
time for their extensive recordings and documentation.
*/

opcode m_scene_bell_noise, a, kkkk
	kBleed, kBass, kBuzz, kType xin

	; Generate a sine wave
	isine ftgenonce 0, 0, 32768, 10, 1

	; Initialise audio output signal
	aOut init 0

	if (kType == 0) then ; local
		; Set up basic variables from parameters
		kBleedVolume = .05 * kBleed
		kBassVolume linlin kBass, 0.1, 0.3
		kBuzzVolume linlin kBuzz, .1, .22
		kHissVolume linlin kBuzz, .03, .07
		kBuzzHp linlin kBuzz, 3840, 5760

		; Trunk bleed
		aBleed1 oscil kBleedVolume, 1540, isine
		aBleed2 oscil kBleedVolume, 1530, isine

	; L	ine buzzing
		aBuzzLow buzz kBassVolume, 120, 2, isine
		aBuzzHigh mpulse kBuzzVolume, 1/120

		; Hissing
		aResNoise wguide1 fractalnoise(kHissVolume,0), 120, 3840, .7

		; Combine the signals and apply filtering
		aHighpass butterhp (aResNoise + aBuzzHigh + aBleed1 + aBleed2), kBuzzHp
		aHighpassBuzz butterhp aBuzzLow, 120
		aLowpass butterlp aHighpass, 9000
		aOut = aLowpass + aHighpassBuzz
	else ; long distance
		kHighpass linlin kBass, 3200, 1600
		kBleedVolume linlin kBleed, .02, .1
		kBuzzVolume linlin kBuzz, .05, .15
		kBeepVolume linlin kBleed, 0, .25

		; Create noise/hiss
		aNoise fractalnoise .25, 1

		; Bleed of the 2600Hz whistle
		aBleed oscili kBleedVolume, 2600, isine

		; Buzzing derived from the noise
		aBuzz wguide1 aNoise*kBuzzVolume, 120, 4000, .8

		; Bleed from other ringing tone(s)
		kGate loopseg, .2, 0, 0, kBeepVolume, 1, kBeepVolume, 0, 0, 4, 0
		aModulator vco2 1, 40, 4, .1
		aBeep oscil aModulator*kGate, 420, isine

		; Filter all signals
		aBandpass zdf_2pole (aNoise + aBuzz + aBleed + aBeep), 1600, 3, 2
		aLowpass zdf_2pole aBandpass, 2000, .5, 0
		aOut zdf_2pole aLowpass, kHighpass, .5, 1

	endif
	
	; Output the audio
	xout aOut
endop
