/*
m_scene_bell_tone - Old American Bell/ATNT call progress tones

DESCRIPTION
m_scene_bell_tone is an opcode to emulate old (1960s and 70s) American Bell/ATNT
telephone progress tones. This is only a subset. In those days the network was
very diverse. This is what you might have heard calling within the cities.
This is modelled in accordance with the specifications. The oscillator shapes
have been slightly tweaked by ear to account for the impurities of the
mechanical equipment in use.

SYNTAX
aOut m_scene_bell_tone Stone

INITIALIZATION
Stone - The tone you want, this is case sensitive. Possible tones:
	dial - dial tone
	busy - busy signal
	ring - ringing or ringback tone
	con - for the connection broken tone (2600Hz beep)
	click: for the click switching from one handler to another

PERFORMANCE

CREDITS
Author: Jeanette C., thanks to Evan Doorbell and other phone phreaks of that
time for extensive recordings and documentation.
*/

opcode m_scene_bell_tone, a, S
	Stone xin

	; Generate a sine wave
	iSine ftgenonce 0, 0, 32768, 10, 1

	if (strcmp(Stone, "dial") == 0) then
		aModulator vco2 1, 120, 4, .07
		aOut oscil aModulator, 600, iSine
	elseif (strcmp(Stone, "ring") == 0) then
		kGate loopseg 1/6, 0, 0, 1, 2, 1, 0, 0, 4, 0, 0
		aModulator vco2 1, 40, 4, .1
		aOut oscil kGate*aModulator, 420, iSine
	elseif (strcmp(Stone, "busy") == 0) then
		kGate loopseg 1, 0, 0, 1, .5, 1, 0, 0, .5, 0, 0
		aModulator vco2 1, 120, 4, .07
		aOut oscil kGate*aModulator, 600, iSine
	elseif (strcmp(Stone, "con") == 0) then
		kGate linseg 1, .02, 1, 0, 0
		aOut oscili kGate, 2600, iSine
	elseif (strcmp(Stone, "click") == 0) then
		kGate linseg .2, .01, .2, 0, 0
		aNoise fractalnoise kGate, 2
		aOut butterlp aNoise, 1000
	endif

	; Output
	xout aOut
endop
